@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2015 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,7 +15,7 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import random as globalrandom
 from random import Random
@@ -23,27 +23,34 @@ from random import Random
 import faker
 from faker.factory import AVAILABLE_LOCALES
 
+from hypothesis._settings import note_deprecation
 from hypothesis.internal.compat import text_type
 from hypothesis.internal.reflection import check_valid_identifier
 from hypothesis.searchstrategy.strategies import SearchStrategy
 
 
 def fake_factory(source, locale=None, locales=None, providers=()):
+    note_deprecation(
+        "hypothesis.extra.fakefactory has been deprecated, because it does "
+        "not support example discovery or shrinking.  Consider using a lower-"
+        "level strategy (such as st.text()) instead.",
+        since="2017-12-02",
+    )
     check_valid_identifier(source)
-    if source[0] == u'_':
-        raise ValueError(u'Bad source name %s' % (source,))
+    if source[0] == u"_":
+        raise ValueError(u"Bad source name %s" % (source,))
 
     if locale is not None and locales is not None:
-        raise ValueError(u'Cannot specify both single and multiple locales')
+        raise ValueError(u"Cannot specify both single and multiple locales")
     if locale:
         locales = (locale,)
     elif locales:
         locales = tuple(locales)
     else:
         locales = None
-    for l in (locales or ()):
+    for l in locales or ():
         if l not in AVAILABLE_LOCALES:
-            raise ValueError(u'Unsupported locale %r' % (l,))
+            raise ValueError(u"Unsupported locale %r" % (l,))
 
     def supports_source(locale):
         test_faker = faker.Faker(locale)
@@ -54,18 +61,15 @@ def fake_factory(source, locale=None, locales=None, providers=()):
     if locales is None:
         locales = list(filter(supports_source, AVAILABLE_LOCALES))
         if not locales:
-            raise ValueError(u'No such source %r' % (source,))
+            raise ValueError(u"No such source %r" % (source,))
     else:
         for l in locales:
             if not supports_source(locale):
-                raise ValueError(u'Unsupported source %s for locale %s' % (
-                    source, l
-                ))
+                raise ValueError(u"Unsupported source %s for locale %s" % (source, l))
     return FakeFactoryStrategy(source, providers, locales)
 
 
 class FakeFactoryStrategy(SearchStrategy):
-
     def __init__(self, source, providers, locales):
         self.source = source
         self.providers = tuple(providers)
@@ -73,8 +77,8 @@ class FakeFactoryStrategy(SearchStrategy):
         self.factories = {}
 
     def do_draw(self, data):
-        seed = data.draw_bytes(4)
-        random = Random(bytes(seed))
+        seed = data.draw_bits(32)
+        random = Random(seed)
         return self.gen_example(random)
 
     def factory_for(self, locale):
