@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,26 +15,33 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-import io
-import uuid
-import decimal
+import collections
 import datetime
+import decimal
 import fractions
 import functools
-import collections
+import io
+import numbers
+import uuid
 
 import hypothesis.strategies as st
 from hypothesis.errors import InvalidArgument, ResolutionFailed
-from hypothesis.internal.compat import PY2, ForwardRef, abc, text_type, \
-    binary_type, typing_root_type
+from hypothesis.internal.compat import (
+    PY2,
+    ForwardRef,
+    abc,
+    binary_type,
+    text_type,
+    typing_root_type,
+)
 
 
 def type_sorting_key(t):
     """Minimise to None, then non-container types, then container types."""
     if not is_a_type(t):
-        raise InvalidArgument('thing=%s must be a type' % (t,))
+        raise InvalidArgument("thing=%s must be a type" % (t,))
     if t is None or t is type(None):  # noqa: E721
         return (-1, repr(t))
     if not isinstance(t, type):  # pragma: no cover
@@ -44,8 +51,8 @@ def type_sorting_key(t):
 
 
 def try_issubclass(thing, superclass):
-    thing = getattr(thing, '__origin__', None) or thing
-    superclass = getattr(superclass, '__origin__', None) or superclass
+    thing = getattr(thing, "__origin__", None) or thing
+    superclass = getattr(superclass, "__origin__", None) or superclass
     try:
         return issubclass(thing, superclass)
     except (AttributeError, TypeError):  # pragma: no cover
@@ -68,42 +75,49 @@ def from_typing_type(thing):
     # Finally, we run a variation of the subclass lookup in st.from_type
     # among generic types in the lookup.
     import typing
+
     # Under 3.6 Union is handled directly in st.from_type, as the argument is
     # not an instance of `type`. However, under Python 3.5 Union *is* a type
     # and we have to handle it here, including failing if it has no parameters.
-    if hasattr(thing, '__union_params__'):  # pragma: no cover
+    if hasattr(thing, "__union_params__"):  # pragma: no cover
         args = sorted(thing.__union_params__ or (), key=type_sorting_key)
         if not args:
-            raise ResolutionFailed('Cannot resolve Union of no types.')
+            raise ResolutionFailed("Cannot resolve Union of no types.")
         return st.one_of([st.from_type(t) for t in args])
-    if getattr(thing, '__origin__', None) == tuple or \
-            isinstance(thing, getattr(typing, 'TupleMeta', ())):
-        elem_types = getattr(thing, '__tuple_params__', None) or ()
-        elem_types += getattr(thing, '__args__', None) or ()
-        if getattr(thing, '__tuple_use_ellipsis__', False) or \
-                len(elem_types) == 2 and elem_types[-1] is Ellipsis:
+    if getattr(thing, "__origin__", None) == tuple or isinstance(
+        thing, getattr(typing, "TupleMeta", ())
+    ):
+        elem_types = getattr(thing, "__tuple_params__", None) or ()
+        elem_types += getattr(thing, "__args__", None) or ()
+        if (
+            getattr(thing, "__tuple_use_ellipsis__", False)
+            or len(elem_types) == 2
+            and elem_types[-1] is Ellipsis
+        ):
             return st.lists(st.from_type(elem_types[0])).map(tuple)
         elif len(elem_types) == 1 and elem_types[0] == ():
             return st.tuples()  # Empty tuple; see issue #1583
         return st.tuples(*map(st.from_type, elem_types))
     if isinstance(thing, typing.TypeVar):
-        if getattr(thing, '__bound__', None) is not None:
+        if getattr(thing, "__bound__", None) is not None:
             return st.from_type(thing.__bound__)
-        if getattr(thing, '__constraints__', None):
+        if getattr(thing, "__constraints__", None):
             return st.shared(
-                st.sampled_from(thing.__constraints__),
-                key='typevar-with-constraint'
+                st.sampled_from(thing.__constraints__), key="typevar-with-constraint"
             ).flatmap(st.from_type)
         # Constraints may be None or () on various Python versions.
         return st.text()  # An arbitrary type for the typevar
     # Now, confirm that we're dealing with a generic type as we expected
     if not isinstance(thing, typing_root_type):  # pragma: no cover
-        raise ResolutionFailed('Cannot resolve %s to a strategy' % (thing,))
+        raise ResolutionFailed("Cannot resolve %s to a strategy" % (thing,))
     # Parametrised generic types have their __origin__ attribute set to the
     # un-parametrised version, which we need to use in the subclass checks.
     # e.g.:     typing.List[int].__origin__ == typing.List
-    mapping = {k: v for k, v in _global_type_lookup.items()
-               if isinstance(k, typing_root_type) and try_issubclass(k, thing)}
+    mapping = {
+        k: v
+        for k, v in _global_type_lookup.items()
+        if isinstance(k, typing_root_type) and try_issubclass(k, thing)
+    }
     if typing.Dict in mapping:
         # The subtype relationships between generic and concrete View types
         # are sometimes inconsistent under Python 3.5, so we pop them out to
@@ -112,14 +126,17 @@ def from_typing_type(thing):
         # such as Container
         for t in (typing.KeysView, typing.ValuesView, typing.ItemsView):
             mapping.pop(t, None)
-    strategies = [v if isinstance(v, st.SearchStrategy) else v(thing)
-                  for k, v in mapping.items()
-                  if sum(try_issubclass(k, T) for T in mapping) == 1]
-    empty = ', '.join(repr(s) for s in strategies if s.is_empty)
+    strategies = [
+        v if isinstance(v, st.SearchStrategy) else v(thing)
+        for k, v in mapping.items()
+        if sum(try_issubclass(k, T) for T in mapping) == 1
+    ]
+    empty = ", ".join(repr(s) for s in strategies if s.is_empty)
     if empty or not strategies:  # pragma: no cover
         raise ResolutionFailed(
-            'Could not resolve %s to a strategy; consider using '
-            'register_type_strategy' % (empty or thing,))
+            "Could not resolve %s to a strategy; consider using "
+            "register_type_strategy" % (empty or thing,)
+        )
     return st.one_of(strategies)
 
 
@@ -145,33 +162,51 @@ _global_type_lookup = {
     frozenset: st.builds(frozenset),
     dict: st.builds(dict),
     # Built-in types
-    type: st.sampled_from([type(None), bool, int, str, list, set, dict]),
     type(Ellipsis): st.just(Ellipsis),
     type(NotImplemented): st.just(NotImplemented),
     bytearray: st.binary().map(bytearray),
     memoryview: st.binary().map(memoryview),
+    numbers.Real: st.floats(),
+    numbers.Rational: st.fractions(),
+    numbers.Number: st.complex_numbers(),
+    numbers.Integral: st.integers(),
+    numbers.Complex: st.complex_numbers(),
     # Pull requests with more types welcome!
 }
 
 if PY2:
-    _global_type_lookup.update({
-        int: st.integers().filter(lambda x: isinstance(x, int)),
-        long: st.integers().map(long)  # noqa
-    })
+    _global_type_lookup.update(
+        {
+            int: st.integers().filter(lambda x: isinstance(x, int)),
+            long: st.integers().map(long),  # noqa
+        }
+    )
+
+_global_type_lookup[type] = st.sampled_from(
+    [type(None)] + sorted(_global_type_lookup, key=str)
+)
 
 try:
     from hypothesis.extra.pytz import timezones
+
     _global_type_lookup[datetime.tzinfo] = timezones()
 except ImportError:  # pragma: no cover
     pass
 try:  # pragma: no cover
     import numpy as np
-    from hypothesis.extra.numpy import \
-        arrays, array_shapes, scalar_dtypes, nested_dtypes
-    _global_type_lookup.update({
-        np.dtype: nested_dtypes(),
-        np.ndarray: arrays(scalar_dtypes(), array_shapes(max_dims=2)),
-    })
+    from hypothesis.extra.numpy import (
+        arrays,
+        array_shapes,
+        scalar_dtypes,
+        nested_dtypes,
+    )
+
+    _global_type_lookup.update(
+        {
+            np.dtype: nested_dtypes(),
+            np.ndarray: arrays(scalar_dtypes(), array_shapes(max_dims=2)),
+        }
+    )
 except ImportError:  # pragma: no cover
     pass
 
@@ -180,16 +215,18 @@ try:
 except ImportError:  # pragma: no cover
     pass
 else:
-    _global_type_lookup.update({
-        typing.ByteString: st.binary(),
-        typing.io.BinaryIO: st.builds(io.BytesIO, st.binary()),  # type: ignore
-        typing.io.TextIO: st.builds(io.StringIO, st.text()),  # type: ignore
-        typing.Reversible: st.lists(st.integers()),
-        typing.SupportsAbs: st.complex_numbers(),
-        typing.SupportsComplex: st.complex_numbers(),
-        typing.SupportsFloat: st.complex_numbers(),
-        typing.SupportsInt: st.complex_numbers(),
-    })
+    _global_type_lookup.update(
+        {
+            typing.ByteString: st.binary(),
+            typing.io.BinaryIO: st.builds(io.BytesIO, st.binary()),  # type: ignore
+            typing.io.TextIO: st.builds(io.StringIO, st.text()),  # type: ignore
+            typing.Reversible: st.lists(st.integers()),
+            typing.SupportsAbs: st.complex_numbers(),
+            typing.SupportsComplex: st.complex_numbers(),
+            typing.SupportsFloat: st.floats(),
+            typing.SupportsInt: st.floats(),
+        }
+    )
 
     try:
         # These aren't present in the typing module backport.
@@ -213,30 +250,33 @@ else:
 
             @functools.wraps(func)
             def really_inner(thing):
-                if getattr(thing, '__args__', None) is None:
+                if getattr(thing, "__args__", None) is None:
                     return fallback
                 return func(thing)
+
             _global_type_lookup[type_] = really_inner
             return really_inner
+
         return inner
 
-    @register('Type')
+    @register("Type")
     def resolve_Type(thing):
         if thing.__args__ is None:
             return st.just(type)
         args = (thing.__args__[0],)
-        if getattr(args[0], '__origin__', None) is typing.Union:
+        if getattr(args[0], "__origin__", None) is typing.Union:
             args = args[0].__args__
-        elif hasattr(args[0], '__union_params__'):  # pragma: no cover
+        elif hasattr(args[0], "__union_params__"):  # pragma: no cover
             args = args[0].__union_params__
         if isinstance(ForwardRef, type):  # pragma: no cover
             # Duplicate check from from_type here - only paying when needed.
             for a in args:
                 if type(a) == ForwardRef:
                     raise ResolutionFailed(
-                        'thing=%s cannot be resolved.  Upgrading to '
-                        'python>=3.6 may fix this problem via improvements '
-                        'to the typing module.' % (thing,))
+                        "thing=%s cannot be resolved.  Upgrading to "
+                        "python>=3.6 may fix this problem via improvements "
+                        "to the typing module." % (thing,)
+                    )
         return st.sampled_from(sorted(args, key=type_sorting_key))
 
     @register(typing.List, st.builds(list))
@@ -257,10 +297,9 @@ else:
         keys_vals = [st.from_type(t) for t in thing.__args__] * 2
         return st.dictionaries(keys_vals[0], keys_vals[1])
 
-    @register('DefaultDict', st.builds(collections.defaultdict))
+    @register("DefaultDict", st.builds(collections.defaultdict))
     def resolve_DefaultDict(thing):
-        return resolve_Dict(thing).map(
-            lambda d: collections.defaultdict(None, d))
+        return resolve_Dict(thing).map(lambda d: collections.defaultdict(None, d))
 
     @register(typing.ItemsView, st.builds(dict).map(dict.items))
     def resolve_ItemsView(thing):
@@ -268,13 +307,15 @@ else:
 
     @register(typing.KeysView, st.builds(dict).map(dict.keys))
     def resolve_KeysView(thing):
-        return st.dictionaries(st.from_type(thing.__args__[0]), st.none()
-                               ).map(dict.keys)
+        return st.dictionaries(st.from_type(thing.__args__[0]), st.none()).map(
+            dict.keys
+        )
 
     @register(typing.ValuesView, st.builds(dict).map(dict.values))
     def resolve_ValuesView(thing):
-        return st.dictionaries(st.integers(), st.from_type(thing.__args__[0])
-                               ).map(dict.values)
+        return st.dictionaries(st.integers(), st.from_type(thing.__args__[0])).map(
+            dict.values
+        )
 
     @register(typing.Iterator, st.iterables(st.nothing()))
     def resolve_Iterator(thing):
